@@ -2,32 +2,9 @@
     crypto/gui/resultlistwidget.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2008 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <config-kleopatra.h>
@@ -37,7 +14,6 @@
 #include "emailoperationspreferences.h"
 
 #include <crypto/gui/resultitemwidget.h>
-#include <crypto/taskcollection.h>
 
 #include <utils/scrollarea.h>
 
@@ -72,23 +48,17 @@ public:
     void resizeIfStandalone();
 
     std::vector< std::shared_ptr<TaskCollection> > m_collections;
-    bool m_standaloneMode;
-    int m_lastErrorItemIndex;
-    ScrollArea *m_scrollArea;
-    QPushButton *m_closeButton;
-    QVBoxLayout *m_layout;
-    QLabel *m_progressLabel;
+    bool m_standaloneMode = false;
+    int m_lastErrorItemIndex = 0;
+    ScrollArea *m_scrollArea = nullptr;
+    QPushButton *m_closeButton = nullptr;
+    QVBoxLayout *m_layout = nullptr;
+    QLabel *m_progressLabel = nullptr;
 };
 
 ResultListWidget::Private::Private(ResultListWidget *qq)
     : q(qq),
-      m_collections(),
-      m_standaloneMode(false),
-      m_lastErrorItemIndex(0),
-      m_scrollArea(nullptr),
-      m_closeButton(nullptr),
-      m_layout(nullptr),
-      m_progressLabel(nullptr)
+      m_collections()
 {
     m_layout = new QVBoxLayout(q);
     m_layout->setContentsMargins(0, 0, 0, 0);
