@@ -1,33 +1,10 @@
 /*  crypto/gui/signencryptwidget.h
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2016 by Bundesamt für Sicherheit in der Informationstechnik
-    Software engineering by Intevation GmbH
+    SPDX-FileCopyrightText: 2016 Bundesamt für Sicherheit in der Informationstechnik
+    SPDX-FileContributor: Intevation GmbH
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef CRYPTO_GUI_SIGNENCRYPTWIDGET_H
 #define CRYPTO_GUI_SIGNENCRYPTWIDGET_H
@@ -125,21 +102,21 @@ Q_SIGNALS:
     void keysChanged();
 
 private:
-    KeySelectionCombo *mSigSelect,
-                      *mSelfSelect;
+    KeySelectionCombo *mSigSelect = nullptr;
+    KeySelectionCombo *mSelfSelect = nullptr;
     QVector<CertificateLineEdit *> mRecpWidgets;
     QVector<UnknownRecipientWidget *> mUnknownWidgets;
     QVector<GpgME::Key> mAddedKeys;
-    QGridLayout *mRecpLayout;
+    QGridLayout *mRecpLayout = nullptr;
     QString mOp;
-    AbstractKeyListModel *mModel;
-    QCheckBox *mSymmetric,
-              *mSigChk,
-              *mEncOtherChk,
-              *mEncSelfChk;
-    int mRecpRowCount;
+    AbstractKeyListModel *mModel = nullptr;
+    QCheckBox *mSymmetric = nullptr;
+    QCheckBox *mSigChk = nullptr;
+    QCheckBox *mEncOtherChk = nullptr;
+    QCheckBox *mEncSelfChk = nullptr;
+    int mRecpRowCount = 2;
     GpgME::Protocol mCurrentProto;
-    bool mIsExclusive;
+    const bool mIsExclusive;
 };
 } // namespace Kleo
 #endif // CRYPTO_GUI_SIGNENCRYPTWIDGET_H
